@@ -1,22 +1,26 @@
 #!/usr/bin/perl
 
 package Test::TAP::Model::Visual;
-use base qw/Test::TAP::Model Test::TAP::Model::Colorful/;
+use base qw/Test::TAP::Model/;
 
 use strict;
 use warnings;
 
+use Test::TAP::Model::Colorful;
 use Test::TAP::Model::File::Visual;
 
 sub file_class { "Test::TAP::Model::File::Visual" }
 
-sub summary {
+sub get_test_files {
 	my $self = shift;
-	$self->{_summar} ||=
-	sprintf "%d test cases: %d ok, %d failed, %d todo, "
-			."%d skipped and %d unexpectedly succeeded",
-			map { my $m = "total_$_"; $self->$m }
-			qw/seen passed failed todo skipped unexpectedly_succeeded/;
+	my $str = $self->desc_string;
+	map { $_->desc_string($str); $_ } $self->SUPER::get_test_files(@_);
+}
+
+sub desc_string {
+	my $self = shift;
+	$self->{_desc_string} = shift if @_;
+	$self->{_desc_string} ||= "";
 }
 
 __PACKAGE__
@@ -52,6 +56,16 @@ details.
 
 A nice little textual summary about the result of the entire test run.
 
+=item desc_string
+
+A short descriptive string used to distinguish this model from others in the
+various consolidated reports.
+
+=item get_test_files
+
+An overridden version of get_test_files which sets C<desc_string> on the files
+based on the one from $self.
+
 =back
 
 =cut
